pub struct DistributedAggregationCollector { /* private fields */ }Expand description
Collector for distributed aggregations.
The collector collects all aggregations by the underlying aggregation request.
Purpose
AggregationCollector returns IntermediateAggregationResults and not the final
AggregationResults, so that results from different indices can be merged and then converted
into the final AggregationResults via the into_final_result() method.
Implementations
Sourceimpl DistributedAggregationCollector
impl DistributedAggregationCollector
Sourcepub fn from_aggs(agg: Aggregations, limits: AggregationLimitsGuard) -> Self
pub fn from_aggs(agg: Aggregations, limits: AggregationLimitsGuard) -> Self
Create collector from aggregation request.
Aggregation fails when the limits in AggregationLimits is exceeded. (memory limit and
bucket limit)