pub enum LockError {
LockBusy,
IoError(Arc<Error>),
}Expand description
Error while trying to acquire a directory lock.
This is returned from Directory::acquire_lock.
Variants
LockBusy
Failed to acquired a lock as it is already held by another client.
- In the context of a blocking lock, this means the lock was not released within some
timeoutperiod. - In the context of a non-blocking lock, this means the lock was busy at the moment of the call.
IoError(Arc<Error>)
Trying to acquire a lock failed with an IoError
Implementations