pub enum OpenReadError {
FileDoesNotExist(PathBuf),
IoError {
io_error: Arc<Error>,
filepath: PathBuf,
},
IncompatibleIndex(Incompatibility),
}Expand description
Error that may occur when accessing a file read
Variants
FileDoesNotExist(PathBuf)
The file does not exist.
IoError
Any kind of io::Error.
Fields
IncompatibleIndex(Incompatibility)
This library does not support the index version found in file footer.
Implementations
Sourceimpl OpenReadError
impl OpenReadError
Sourcepub fn wrap_io_error(io_error: Error, filepath: PathBuf) -> Self
pub fn wrap_io_error(io_error: Error, filepath: PathBuf) -> Self
Wraps an io error.