pub enum OpenWriteError {
FileAlreadyExists(PathBuf),
IoError {
io_error: Arc<Error>,
filepath: PathBuf,
},
}Expand description
Error that may occur when starting to write in a file
Variants
FileAlreadyExists(PathBuf)
Our directory is WORM, writing an existing file is forbidden.
Checkout the Directory documentation.
IoError
Any kind of IO error that happens when writing in the underlying IO device.
Implementations
Sourceimpl OpenWriteError
impl OpenWriteError
Sourcepub fn wrap_io_error(io_error: Error, filepath: PathBuf) -> Self
pub fn wrap_io_error(io_error: Error, filepath: PathBuf) -> Self
Wraps an io error.