ConstScoreQuery

Struct ConstScoreQuery 

pub struct ConstScoreQuery { /* private fields */ }
ConstScoreQuery is a wrapper over a query to provide a constant score. It can avoid unnecessary score computation on the wrapped query.

The document set matched by the ConstScoreQuery is strictly the same as the underlying query. The configured score is used for each document.

Implementations

Source

impl ConstScoreQuery

pub fn new(query: Box<dyn Query>, score: Score) -> ConstScoreQuery

Builds a const score query.