InvertedIndexRangeQuery

Struct InvertedIndexRangeQuery 

pub struct InvertedIndexRangeQuery { /* private fields */ }
InvertedIndexRangeQuery is the same as RangeQuery but only uses the inverted index

Implementations

Source

impl InvertedIndexRangeQuery

pub fn new( lower_bound: Bound<Term>, upper_bound: Bound<Term>, ) -> InvertedIndexRangeQuery

Create new InvertedIndexRangeQuery

pub fn limit(&mut self, limit: u64)

Limit the number of term the RangeQuery will go through.

This does not limit the number of matching document, only the number of different terms that get matched.