pub struct TermQuery { /* private fields */ }Expand description
A Term query matches all of the documents containing a specific term.
The score associated is defined as
idf * sqrt(term_freq / field norm)
in which :
idf- inverse document frequency.term_freq- number of occurrences of the term in the fieldfield norm- number of tokens in the field.
use tantivy::collector::{Count, TopDocs};
use tantivy::query::TermQuery;
use tantivy::schema::{Schema, TEXT, IndexRecordOption};
use tantivy::{doc, Index, IndexWriter, Term};
let mut schema_builder = Schema::builder();
let title = schema_builder.add_text_field("title", TEXT);
let schema = schema_builder.build();
let index = Index::create_in_ram(schema);
{
let mut index_writer: IndexWriter = index.writer(15_000_000)?;
index_writer.add_document(doc!(
title => "The Name of the Wind",
))?;
index_writer.add_document(doc!(
title => "The Diary of Muadib",
))?;
index_writer.add_document(doc!(
title => "A Dairy Cow",
))?;
index_writer.add_document(doc!(
title => "The Diary of a Young Girl",
))?;
index_writer.commit()?;
}
let reader = index.reader()?;
let searcher = reader.searcher();
let query = TermQuery::new(
Term::from_field_text(title, "diary"),
IndexRecordOption::Basic,
);
let (top_docs, count) = searcher.search(&query, &(TopDocs::with_limit(2), Count))?;
assert_eq!(count, 2);
Ok(())Implementations
Sourceimpl TermQuery
impl TermQuery
Sourcepub fn new(term: Term, segment_postings_options: IndexRecordOption) -> TermQuery
pub fn new(term: Term, segment_postings_options: IndexRecordOption) -> TermQuery
Creates a new term query.
Sourcepub fn specialized_weight(
&self,
enable_scoring: EnableScoring<'_>,
) -> Result<TermWeight>
pub fn specialized_weight( &self, enable_scoring: EnableScoring<'_>, ) -> Result<TermWeight>
Returns a weight object.
While .weight(...) returns a boxed trait object,
this method return a specific implementation.
This is useful for optimization purpose.