BytesOptions

Struct BytesOptions 

pub struct BytesOptions { /* private fields */ }
Define how a bytes field should be handled by tantivy.

Implementations

Source

impl BytesOptions

pub fn is_indexed(&self) -> bool

Returns true if the value is indexed.

pub fn fieldnorms(&self) -> bool

Returns true if and only if the value is normed.

pub fn is_fast(&self) -> bool

Returns true if the value is a fast field.

pub fn is_stored(&self) -> bool

Returns true if the value is stored.

pub fn set_indexed(self) -> BytesOptions

Set the field as indexed.

Setting an integer as indexed will generate a posting list for each value taken by the integer.

pub fn set_fieldnorms(self) -> BytesOptions

Set the field as normed.

Setting an integer as normed will generate the fieldnorm data for it.

pub fn set_fast(self) -> BytesOptions

Set the field as a fast field.

Fast fields are designed for random access.

pub fn set_stored(self) -> BytesOptions

Set the field as stored.

Only the fields that are set as stored are persisted into the Tantivy’s store.