pub struct ExistsQuery { /* private fields */ }Expand description
Query that matches all documents with a non-null value in the specified field.
When querying inside a JSON field, “exists” queries can be executed strictly
on the field name or check all the subpaths. In that second case a document
will be matched if a non-null value exists in any subpath. For example,
assuming the following document where myfield is a JSON fast field:
{
"myfield": {
"mysubfield": "hello"
}
}With json_subpaths enabled queries on either myfield or
myfield.mysubfield will match the document. If it is set to false, only
myfield.mysubfield will match it.
All of the matched documents get the score 1.0.
Implementations
Sourceimpl ExistsQuery
impl ExistsQuery
Sourcepub fn new_exists_query(field: String) -> ExistsQuery
👎Deprecated
pub fn new_exists_query(field: String) -> ExistsQuery
Creates a new ExistQuery from the given field.
This query matches all documents with at least one non-null value in the specified field. This constructor never fails, but executing the search with this query will return an error if the specified field doesn’t exists or is not a fast field.
Sourcepub fn new(field: String, json_subpaths: bool) -> Self
pub fn new(field: String, json_subpaths: bool) -> Self
Creates a new ExistQuery from the given field.
This query matches all documents with at least one non-null value in the
specified field. If json_subpaths is set to true, documents with
non-null values in any JSON subpath will also be matched.
This constructor never fails, but executing the search with this query will return an error if the specified field doesn’t exists or is not a fast field.