pub struct RangeQuery { /* private fields */ }Expand description
RangeQuery matches all documents that have at least one term within a defined range.
Matched document will all get a constant Score of one.
Implementation
Default
The default implementation collects all documents upfront into a BitSet.
This is done by iterating over the terms within the range and loading all docs for each
TermInfo from the inverted index (posting list) and put them into a BitSet.
Depending on the number of terms matched, this is a potentially expensive operation.
IP fast field
For IP fast fields a custom variant is used, by scanning the fast field. Unlike the default variant we can walk in a lazy fashion over it, since the fastfield is implicit orderered by DocId.
Example
use tantivy::collector::Count;
use tantivy::query::RangeQuery;
use tantivy::Term;
use tantivy::schema::{Schema, INDEXED};
use tantivy::{doc, Index, IndexWriter};
use std::ops::Bound;
let mut schema_builder = Schema::builder();
let year_field = schema_builder.add_u64_field("year", INDEXED);
let schema = schema_builder.build();
let index = Index::create_in_ram(schema);
let mut index_writer: IndexWriter = index.writer_with_num_threads(1, 20_000_000)?;
for year in 1950u64..2017u64 {
let num_docs_within_year = 10 + (year - 1950) * (year - 1950);
for _ in 0..num_docs_within_year {
index_writer.add_document(doc!(year_field => year))?;
}
}
index_writer.commit()?;
let reader = index.reader()?;
let searcher = reader.searcher();
let docs_in_the_sixties = RangeQuery::new(
Bound::Included(Term::from_field_u64(year_field, 1960)),
Bound::Excluded(Term::from_field_u64(year_field, 1970)),
);
let num_60s_books = searcher.search(&docs_in_the_sixties, &Count)?;
assert_eq!(num_60s_books, 2285);
Ok(())Implementations
Sourceimpl RangeQuery
impl RangeQuery
Sourcepub fn new(lower_bound: Bound<Term>, upper_bound: Bound<Term>) -> RangeQuery
pub fn new(lower_bound: Bound<Term>, upper_bound: Bound<Term>) -> RangeQuery
Creates a new RangeQuery from bounded start and end terms.
If the value type is not correct, something may go terribly wrong when
the Weight object is created.
Sourcepub fn value_type(&self) -> Type
pub fn value_type(&self) -> Type
The value type of the field