pub struct BytesOptions { /* private fields */ }Expand description
Define how a bytes field should be handled by tantivy.
Implementations
Sourceimpl BytesOptions
impl BytesOptions
Sourcepub fn is_indexed(&self) -> bool
pub fn is_indexed(&self) -> bool
Returns true if the value is indexed.
Sourcepub fn fieldnorms(&self) -> bool
pub fn fieldnorms(&self) -> bool
Returns true if and only if the value is normed.
Sourcepub fn set_indexed(self) -> BytesOptions
pub fn set_indexed(self) -> BytesOptions
Set the field as indexed.
Setting an integer as indexed will generate a posting list for each value taken by the integer.
Sourcepub fn set_fieldnorms(self) -> BytesOptions
pub fn set_fieldnorms(self) -> BytesOptions
Set the field as normed.
Setting an integer as normed will generate the fieldnorm data for it.
Sourcepub fn set_fast(self) -> BytesOptions
pub fn set_fast(self) -> BytesOptions
Set the field as a fast field.
Fast fields are designed for random access.
Sourcepub fn set_stored(self) -> BytesOptions
pub fn set_stored(self) -> BytesOptions
Set the field as stored.
Only the fields that are set as stored are persisted into the Tantivy’s store.